@@ -33,6 +33,7 @@ extern crate libpulse_sys as pulse;
 extern crate glib_sys as glib;
 
 use glib::GMainContext;
+use pulse::mainloop::api::pa_mainloop_api;
 
 /// An opaque GLIB main loop object.
 #[repr(C)] pub struct pa_glib_mainloop { _private: [u8; 0] }
@@ -41,5 +42,5 @@ use glib::GMainContext;
 extern "C" {
     pub fn pa_glib_mainloop_new(c: *mut GMainContext) -> *mut pa_glib_mainloop;
     pub fn pa_glib_mainloop_free(g: *mut pa_glib_mainloop);
-    pub fn pa_glib_mainloop_get_api(g: *const pa_glib_mainloop) -> *const ::pulse::mainloop::api::pa_mainloop_api;
+    pub fn pa_glib_mainloop_get_api(g: *const pa_glib_mainloop) -> *const pa_mainloop_api;
 }
